@@ -1,11 +1,11 @@
 """Contains methods for building out SQL."""
 from typing import Any, List, Mapping, Optional, Set, Tuple
 
-from apgw.constraint import (Assignments, BinaryConstraint, Constraints,
-                             DictConstraint, GroupConstraint, Literal,
-                             MappedPlaceholder, TextConstraint)
-from apgw.types import SQL, InsertAssignments, LimitOffset, Record
-from apgw.util import constraint_list_to_sql
+from .constraint import (Assignments, BinaryConstraint, Constraints,
+                         DictConstraint, GroupConstraint, Literal,
+                         MappedPlaceholder, TextConstraint)
+from .types import SQL, InsertAssignments, LimitOffset, Record
+from .util import constraint_list_to_sql
 
 
 def diff(source: Record, updates: Record, keys: Optional[Set[str]] = None) -> Record:
