@@ -61,15 +61,13 @@ class DBBase:
     async def get_connection_args(self) -> ConnectionArgs:
         raise NotImplementedError()
 
-    @staticmethod
-    async def connect(connection_args: ConnectionArgs) -> "Connection":
+    async def connect(self, connection_args: ConnectionArgs) -> "Connection":
         """Override this method to customize how the connection is open. For instance you could
         use a connection pool's acquire method.
         """
         return await connect(**connection_args)
 
-    @staticmethod
-    async def disconnect(connection: Connection):
+    async def disconnect(self, connection: Connection):
         """Override this method to customize how the connection is closed. For instance you could
         use a connection pool's release method.
         """
