@@ -1,8 +1,8 @@
 """Contains util methods."""
 from typing import List
 
-from apgw.constraint import BinaryConstraint, Literal, MappedPlaceholder
-from apgw.types import SQL, Params
+from .constraint import BinaryConstraint, Literal, MappedPlaceholder
+from .types import SQL, Params
 
 
 def constraint_list_to_sql(
